---
template: mainpanel
source_form: markdown
name: Trello Cardlist Project Stage
updated: October 2016
title: Trello Cardlist Project Stage
---
### Project Stage

* HEADLINE: PRE-ALPHA
* DEV STATE: WORKING (USABLE)
* DEV VERSION: 0.1.23
* RELEASED: 0.0.22 (25 Sep 2016)
* LANGUAGE STATE: BARE*
* FOCUS: Practicalities (Arduino Profile real example) - Get the Puppy/Kitten Robot working
* Newsletter created at http://tinyletter.com/sparkslabs
